@@ -1,21 +1,18 @@
 package Linux::Smaps::Tiny::PP;
-BEGIN {
-  $Linux::Smaps::Tiny::PP::AUTHORITY = 'cpan:AVAR';
-}
-{
-  $Linux::Smaps::Tiny::PP::VERSION = '0.10';
-}
+BEGIN { $Linux::Smaps::Tiny::PP::VERSION = '0.11'; }
 use strict;
 use warnings FATAL => "all";
+use Exporter 'import';
+our @EXPORT_OK = qw(get_smaps_summary);
 
-sub __get_smaps_summary {
+sub get_smaps_summary {
     my $proc_id= shift || "self";
     my $smaps_file= "/proc/$proc_id/smaps";
     open my $fh, "<", $smaps_file
         or do {
             my $errnum= 0+$!; # numify
             my $errmsg= "$!"; # stringify
-            my $msg= "In get_smaps_summary, failed to read '$smaps_file': [$errnum] $errmsg";
+            my $msg= "In get_smaps_summary: Failed to read '$smaps_file': [$errnum] $errmsg";
 
             die $msg;
         };
